BagEndsConfig = {}

SLASH_BAGENDS1, SLASH_BAGENDS2 = "/bagends", "/be"

local BagEndsFrame = CreateFrame( "Frame", "BagEndsConfigFrame", InterfaceOptionsFramePanelContainer)
local Title = BagEndsConfigFrame:CreateFontString( "BagEndsTitle", nil, "GameFontNormalLarge")
local OutlineToggle = CreateFrame( "CheckButton", "BagEndsOutlineToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local TextToggle = CreateFrame( "CheckButton", "BagEndsTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ColorToggle = CreateFrame( "CheckButton", "BagEndsColorToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local OccupiedToggle = CreateFrame( "CheckButton", "BagEndsOccupiedToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ShowTotalToggle = CreateFrame( "CheckButton", "BagEndsTotalToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )

local function SetDefaults()
	BagEndsConfig.outline = true
	BagEndsConfig.showText = true
	BagEndsConfig.colorText = false
	BagEndsConfig.occupied = false
	BagEndsConfig.showTotal = true
	BagEndsConfig.savedVariables = true
end

local function SpewMessage(handle, msg)
	if handle == "loaded" then
		print("|cFFFFCC00" .. GetAddOnMetadata("BagEnds", "Title") .. "|r v|cFF00FF00" .. GetAddOnMetadata("BagEnds", "Version") .. "|r Loaded - Use |cAAFFCC00" .. SLASH_BAGENDS1 .. "|r or |cAAFFCC00" .. SLASH_BAGENDS2 .. "|r for help!")
	elseif handle == "help" then
		print("Use |cFFFFCC00" .. SLASH_BAGENDS1 .. "|r or |cFFFFCC00" .. SLASH_BAGENDS2 .. "|r followed by one of the following commands:")
		SpewMessage("config", "shows the Bag Ends options frame")
		SpewMessage("outline", "toggles showing of the bag status outline")
		SpewMessage("text", "toggles showing of the bag status text")
		SpewMessage("color", "toggles color of the bag status text")
		SpewMessage("free", "toggles counting FREE or FULL bag slots")
		SpewMessage("total", "toggles appending the total bag size to status text")
	else
		print("|cFFFFCC00" .. handle .. "|r - " .. msg)
	end
end

local function UpdateConfig()
	
	BagEndsConfig.outline = BagEndsOutlineToggle:GetChecked()
	BagEndsConfig.showText = BagEndsTextToggle:GetChecked()
	
	if (BagEndsConfig.showText) then
		
		BagEndsColorToggle:Enable()
		BagEndsOccupiedToggle:Enable()
		BagEndsTotalToggle:Enable()
		
		BagEndsConfig.colorText = BagEndsColorToggle:GetChecked()
		BagEndsConfig.occupied = BagEndsOccupiedToggle:GetChecked()
		BagEndsConfig.showTotal = BagEndsTotalToggle:GetChecked()
	
	else
	
		BagEndsColorToggle:Disable()
		BagEndsOccupiedToggle:Disable()
		BagEndsTotalToggle:Disable()
		
	end

	BagEndsUpdate()
end

local function BagEndsConfigInit()
	BagEndsFrame.name = "Bag Ends"
 
	BagEndsTitle:SetPoint("TOPLEFT", 16,-16)
	BagEndsTitle:SetText("Bag Ends")
 
	BagEndsTextToggle:SetPoint( "TOPLEFT", 16, -48 )
	BagEndsTextToggle:SetScript("OnClick", UpdateConfig)
	BagEndsTextToggle:SetChecked(BagEndsConfig.showText)
	BagEndsTextToggleText:SetText("Show Bag Status Text")
	BagEndsTextToggle.tooltipText = "Toggles Status Text. Useful if you only want Status Outlines."
		
	BagEndsColorToggle:SetPoint( "TOPLEFT", 32, -80 )
	BagEndsColorToggle:SetScript("OnClick", UpdateConfig)
	BagEndsColorToggle:SetChecked(BagEndsConfig.colorText)
	BagEndsColorToggleText:SetText("Color Status Text")
	BagEndsColorToggle.tooltipText = "Color the Status Text to indicate how full a bag is."
	
	BagEndsOccupiedToggle:SetPoint( "TOPLEFT", 32, -112 )
	BagEndsOccupiedToggle:SetScript("OnClick", UpdateConfig)
	BagEndsOccupiedToggle:SetChecked(BagEndsConfig.occupied)
	BagEndsOccupiedToggleText:SetText("Count Full Bag Slots")
	BagEndsOccupiedToggle.tooltipText = "Toggle between the display of FREE bag slots or FULL bag slots."
	
	BagEndsTotalToggle:SetPoint( "TOPLEFT", 32, -144 )
	BagEndsTotalToggle:SetScript("OnClick", UpdateConfig)
	BagEndsTotalToggle:SetChecked(BagEndsConfig.showTotal)
	BagEndsTotalToggleText:SetText("Show Total Bag Size")
	BagEndsTotalToggle.tooltipText = "Append the bag size to the Status Text."

	BagEndsOutlineToggle:SetPoint( "TOPLEFT", 16, -176 )
	BagEndsOutlineToggle:SetScript("OnClick", UpdateConfig)
	BagEndsOutlineToggle:SetChecked(BagEndsConfig.outline)
	BagEndsOutlineToggleText:SetText("Show Bag Status Outline")
	BagEndsOutlineToggle.tooltipText = "Toggle Status Outlines. Useful if you only want Status Text"
	
	if (BagEndsConfig.showText == false) then
		BagEndsColorToggle:Disable()
		BagEndsOccupiedToggle:Disable()
		BagEndsTotalToggle:Disable()
	end
	
	InterfaceOptions_AddCategory(BagEndsFrame)
end

function BagEndsEventHandler(event, arg1)
	if (BagEndsConfig.savedVariables) then
		BagEndsConfigInit()
	else
		SetDefaults()
		BagEndsConfigInit()
	end
	SpewMessage("loaded")
end


function SlashCmdList.BAGENDS(msg, editbox)
	if msg == "config" then
		InterfaceOptionsFrame_OpenToCategory(BagEndsFrame);
	elseif msg == "outline" then
		BagEndsOutlineToggle:SetChecked(not BagEndsOutlineToggle:GetChecked())
		UpdateConfig()
	elseif msg == "text" then
		BagEndsTextToggle:SetChecked(not BagEndsTextToggle:GetChecked())
		UpdateConfig()
	elseif msg == "color" then
		BagEndsColorToggle:SetChecked(not BagEndsColorToggle:GetChecked())
		UpdateConfig()
	elseif msg == "free" then
		BagEndsOccupiedToggle:SetChecked(not BagEndsOccupiedToggle:GetChecked())
		UpdateConfig()
	elseif msg == "total" then
		BagEndsTotalToggle:SetChecked(not BagEndsTotalToggle:GetChecked())
		UpdateConfig()		
	else
		SpewMessage("help")
	end
end

BagEndsFrame:RegisterEvent("VARIABLES_LOADED")
BagEndsFrame:SetScript("OnEvent", BagEndsEventHandler)